@@ -64,6 +64,11 @@ _NAME_TO_COLOR = {
     'gray': '#555',
     'lightgrey': '#9f9f9f',
     'lightgray': '#9f9f9f',
+    'critical': '#e05d44',
+    'important': '#fe7d37',
+    'success': '#4c1',
+    'informational': '#007ec6',
+    'inactive': '#9f9f9f',
 }
 
 
@@ -114,18 +119,25 @@ def _embed_image(url: str) -> str:
 
 def badge(
     left_text: str,
-    right_text: str,
+    right_text: Optional[str] = None,
     left_link: Optional[str] = None,
     right_link: Optional[str] = None,
+    center_link: Optional[str] = None,
     whole_link: Optional[str] = None,
     logo: Optional[str] = None,
     left_color: str = '#555',
     right_color: str = '#007ec6',
+    center_color: Optional[str] = None,
     measurer: Optional[text_measurer.TextMeasurer] = None,
-    embed_logo: bool = False,
-    whole_title: Optional[str] = None,
     left_title: Optional[str] = None,
     right_title: Optional[str] = None,
+    center_title: Optional[str] = None,
+    whole_title: Optional[str] = None,
+    right_image: Optional[str] = None,
+    center_image: Optional[str] = None,
+    embed_logo: bool = False,
+    embed_right_image: bool = False,
+    embed_center_image: bool = False,
     id_suffix: str = '',
 ) -> str:
     """Creates a github-style badge as an SVG image.
@@ -153,12 +165,12 @@ def badge(
             text. Can be an valid CSS color
             (see https://developer.mozilla.org/en-US/docs/Web/CSS/color) or a
             color name defined here:
-            https://github.com/badges/shields/blob/master/lib/colorscheme.json
+            https://github.com/badges/shields/blob/master/badge-maker/lib/color.js
         right_color: The color of the part of the badge containing the
             right-hand text. Can be an valid CSS color
             (see https://developer.mozilla.org/en-US/docs/Web/CSS/color) or a
             color name defined here:
-            https://github.com/badges/shields/blob/master/lib/colorscheme.json
+            https://github.com/badges/shields/blob/master/badge-maker/lib/color.js
         measurer: A text_measurer.TextMeasurer that can be used to measure the
             width of left_text and right_text.
         embed_logo: If True then embed the logo image directly in the badge.
@@ -182,28 +194,55 @@ def badge(
         measurer = (
             precalculated_text_measurer.PrecalculatedTextMeasurer.default())
 
-    if (left_link or right_link) and whole_link:
+    if (left_link or right_link or center_link) and whole_link:
         raise ValueError(
-            'whole_link may not bet set with left_link or right_link')
-    template = _JINJA2_ENVIRONMENT.get_template('badge-template-full.svg')
+            'whole_link may not bet set with left_link, right_link, or center_link'
+        )
+
+    if center_image and not (right_image or right_text):
+        raise ValueError('cannot have a center_image without a right element')
+
+    if (center_image and not center_color) or (not center_image and
+                                               center_color):
+        raise ValueError('must have both a center_image and a center_color')
 
     if logo and embed_logo:
         logo = _embed_image(logo)
 
+    if right_image and embed_right_image:
+        right_image = _embed_image(right_image)
+
+    if center_image and embed_center_image:
+        center_image = _embed_image(center_image)
+
+    if center_color:
+        center_color = _NAME_TO_COLOR.get(center_color, center_color)
+
+    right_text_width = None
+    if right_text:
+        right_text_width = measurer.text_width(right_text) / 10.0
+
+    template = _JINJA2_ENVIRONMENT.get_template('badge-template-full.svg')
+
     svg = template.render(
         left_text=left_text,
         right_text=right_text,
         left_text_width=measurer.text_width(left_text) / 10.0,
-        right_text_width=measurer.text_width(right_text) / 10.0,
+        right_text_width=right_text_width,
         left_link=left_link,
         right_link=right_link,
         whole_link=whole_link,
+        center_link=center_link,
         logo=logo,
         left_color=_NAME_TO_COLOR.get(left_color, left_color),
         right_color=_NAME_TO_COLOR.get(right_color, right_color),
-        whole_title=whole_title,
+        center_color=center_color,
         left_title=left_title,
         right_title=right_title,
+        center_title=center_title,
+        whole_title=whole_title,
+        right_image=right_image,
+        center_image=center_image,
         id_suffix=id_suffix,
     )
     xml = minidom.parseString(svg)
