@@ -22,6 +22,7 @@ import sys
 import tempfile
 import webbrowser
 
+sys.path.append('/home/nick/git/pybadges/')
 import pybadges
 from pybadges.version import __version__
 
@@ -37,11 +38,8 @@ def main():
         help='the text to show on the left-hand-side of the badge')
     parser.add_argument(
         '--right-text',
-        default='APACHE',
+        default=None,
         help='the text to show on the right-hand-side of the badge')
-    parser.add_argument('--whole-link',
-                        default=None,
-                        help='the url to redirect to when the badge is clicked')
     parser.add_argument(
         '--left-link',
         default=None,
@@ -52,6 +50,18 @@ def main():
         default=None,
         help='the url to redirect to when the right-hand of the badge is ' +
         'clicked')
+    parser.add_argument(
+        '--center-link',
+        default=None,
+        help='the url to redirect to when the center of the badge is ' +
+        'clicked')
+    parser.add_argument('--whole-link',
+                        default=None,
+                        help='the url to redirect to when the badge is clicked')
+    parser.add_argument(
+        '--logo',
+        default=None,
+        help='a URI reference to a logo to display in the badge')
     parser.add_argument(
         '--left-color',
         default='#555',
@@ -61,19 +71,9 @@ def main():
         default='#007ec6',
         help='the background color of the right-hand-side of the badge')
     parser.add_argument(
-        '--logo',
+        '--center-color',
         default=None,
-        help='a URI reference to a logo to display in the badge')
-    parser.add_argument(
-        '--embed-logo',
-        nargs='?',
-        type=lambda x: x.lower() in ['y', 'yes', 't', 'true', '1', ''],
-        const='yes',
-        default='no',
-        help='if the logo is specified then include the image data directly in '
-        'the badge (this will prevent a URL fetch and may work around the '
-        'fact that some browsers do not fetch external image references); '
-        'only works if --logo is a HTTP/HTTPS URI or a file path')
+        help='the background color of the right-hand-side of the badge')
     parser.add_argument('--browser',
                         action='store_true',
                         default=False,
@@ -91,11 +91,6 @@ def main():
         help='the path to the ttf font file containing DejaVu Sans. If not ' +
         'present on your system, you can download it from ' +
         'https://www.fontsquirrel.com/fonts/dejavu-sans')
-    parser.add_argument(
-        '--whole-title',
-        default=None,
-        help='the title to associate with the entire badge. See '
-        'https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title')
     parser.add_argument(
         '--left-title',
         default=None,
@@ -106,6 +101,56 @@ def main():
         default=None,
         help='the title to associate with the right part of the badge. See '
         'https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title')
+    parser.add_argument(
+        '--center-title',
+        default=None,
+        help='the title to associate with the center part of the badge. See '
+        'https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title')
+    parser.add_argument(
+        '--whole-title',
+        default=None,
+        help='the title to associate with the entire badge. See '
+        'https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title')
+    parser.add_argument(
+        '--right-image',
+        default=None,
+        help='the image to associate with the right-hand side of the badge')
+    parser.add_argument(
+        '--center-image',
+        default=None,
+        help='the image to associate with the center of the badge')
+    parser.add_argument(
+        '--embed-logo',
+        nargs='?',
+        type=lambda x: x.lower() in ['y', 'yes', 't', 'true', '1', ''],
+        const='yes',
+        default='no',
+        help='if the logo is specified then include the image data directly in '
+        'the badge (this will prevent a URL fetch and may work around the '
+        'fact that some browsers do not fetch external image references); '
+        'only works if --logo is a HTTP/HTTPS URI or a file path')
+    parser.add_argument(
+        '--embed-right-image',
+        nargs='?',
+        type=lambda x: x.lower() in ['y', 'yes', 't', 'true', '1', ''],
+        const='yes',
+        default='no',
+        help=
+        'if the right image is specified then include the image data directly in '
+        'the badge (this will prevent a URL fetch and may work around the '
+        'fact that some browsers do not fetch external image references); '
+        'only works if --logo is a HTTP/HTTPS URI or a file path')
+    parser.add_argument(
+        '--embed-center-image',
+        nargs='?',
+        type=lambda x: x.lower() in ['y', 'yes', 't', 'true', '1', ''],
+        const='yes',
+        default='no',
+        help=
+        'if the center image is specified then include the image data directly in '
+        'the badge (this will prevent a URL fetch and may work around the '
+        'fact that some browsers do not fetch external image references); '
+        'only works if --logo is a HTTP/HTTPS URI or a file path')
     parser.add_argument(
         '-v',
         '--version',
@@ -113,9 +158,10 @@ def main():
         version='%(prog)s {version}'.format(version=__version__))
     args = parser.parse_args()
 
-    if (args.left_link or args.right_link) and args.whole_link:
+    if (args.left_link or args.right_link or
+            args.center_link) and args.whole_link:
         print('argument --whole-link: cannot be set with ' +
-              '--left-link or --right-link',
+              '--left-link, --right-link, or --center_link',
               file=sys.stderr)
         sys.exit(1)
 
@@ -133,15 +179,22 @@ def main():
                            right_text=args.right_text,
                            left_link=args.left_link,
                            right_link=args.right_link,
+                           center_link=args.center_link,
                            whole_link=args.whole_link,
+                           logo=args.logo,
                            left_color=args.left_color,
                            right_color=args.right_color,
-                           logo=args.logo,
+                           center_color=args.center_color,
                            measurer=measurer,
-                           embed_logo=args.embed_logo,
-                           whole_title=args.whole_title,
                            left_title=args.left_title,
-                           right_title=args.right_title)
+                           right_title=args.right_title,
+                           center_title=args.center_title,
+                           whole_title=args.whole_title,
+                           right_image=args.right_image,
+                           center_image=args.center_image,
+                           embed_logo=args.embed_logo,
+                           embed_right_image=args.embed_right_image,
+                           embed_center_image=args.embed_center_image)
 
     if args.browser:
         _, badge_path = tempfile.mkstemp(suffix='.svg')
