@@ -17,13 +17,14 @@ import base64
 import doctest
 import json
 import os.path
-import unittest
 import pathlib
 import sys
 import tempfile
+import unittest
 import xmldiff.main
 
 import pybadges
+from tests import image_server
 
 TEST_DIR = os.path.dirname(__file__)
 
@@ -36,6 +37,15 @@ PNG_IMAGE = base64.b64decode(PNG_IMAGE_B64)
 class TestPybadgesBadge(unittest.TestCase):
     """Tests for pybadges.badge."""
 
+    def setUp(self):
+        super().setUp()
+        self._image_server = image_server.ImageServer(PNG_IMAGE)
+        self._image_server.start_server()
+
+    def tearDown(self):
+        super().tearDown()
+        self._image_server.stop_server()
+
     def test_docs(self):
         doctest.testmod(pybadges, optionflags=doctest.ELLIPSIS)
 
@@ -51,16 +61,36 @@ class TestPybadgesBadge(unittest.TestCase):
             examples = json.load(f)
 
         for example in examples:
+            self._image_server.fix_embedded_url_reference(example)
             file_name = example.pop('file_name')
             with self.subTest(example=file_name):
-                filepath = os.path.join(TEST_DIR, 'golden-images', file_name)
+                goldenpath = os.path.join(TEST_DIR, 'golden-images', file_name)
 
-                with open(filepath, mode="r", encoding="utf-8") as f:
+                with open(goldenpath, mode="r", encoding="utf-8") as f:
                     golden_image = f.read()
                 pybadge_image = pybadges.badge(**example)
 
                 diff = xmldiff.main.diff_texts(golden_image, pybadge_image)
-                self.assertFalse(diff)
+                if diff:
+                    with tempfile.NamedTemporaryFile(mode="w+t",
+                                                     encoding="utf-8",
+                                                     delete=False,
+                                                     suffix=".svg") as actual:
+                        actual.write(pybadge_image)
+
+                    with tempfile.NamedTemporaryFile(mode="w+t",
+                                                     delete=False,
+                                                     suffix=".html") as html:
+                        html.write("""
+                        <html>
+                            <body>
+                                <img src="file://%s"><br>
+                                <img src="file://%s">
+                            <body>
+                        </html>""" % (goldenpath, actual.name))
+                    self.fail(
+                        "images for %s differ:\n%s\nview with:\npython -m webbrowser %s"
+                        % (file_name, diff, html.name))
 
 
 class TestEmbedImage(unittest.TestCase):
